<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../src/dialogs/aboutdialog.cpp" line="45"/>
        <source>About &lt;AppName&gt;</source>
        <translation>À propos de &lt;AppName&gt;</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/aboutdialog.cpp" line="59"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
<context>
    <name>ConfigEditor</name>
    <message>
        <location filename="../../src/dialogs/configeditor.cpp" line="49"/>
        <source>&lt;ParentName&gt; Config Editor</source>
        <translation>Éditeur de configuration &lt;ParentName&gt;</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/configeditor.cpp" line="73"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <location filename="../../src/dialogs/downloaddialog.cpp" line="50"/>
        <source>Search Game Information</source>
        <translation>Chercher des informations sur le jeu</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/downloaddialog.cpp" line="54"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/downloaddialog.cpp" line="56"/>
        <source>Name of Game:</source>
        <translation>Nom du jeu :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/downloaddialog.cpp" line="57"/>
        <source>or Game ID:</source>
        <translation>ou identifiant du jeu :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/downloaddialog.cpp" line="63"/>
        <source>From thegamesdb.net URL of game</source>
        <translation>URL du jeu sur thegamesdb.net</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/downloaddialog.cpp" line="66"/>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
</context>
<context>
    <name>EmulatorHandler</name>
    <message>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="62"/>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="190"/>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="197"/>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="207"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="63"/>
        <source>&lt;ParentName&gt; quit unexpectedly. Check the log for more information.</source>
        <translation>&lt;ParentName&gt; a quitté de manière inattendue. Consultez les journaux pour plus d&apos;informations.</translation>
    </message>
    <message>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="67"/>
        <source>View Log...</source>
        <translation>Consulter les journaux...</translation>
    </message>
    <message>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="191"/>
        <source>&lt;ParentName&gt; executable not found.</source>
        <translation>Executable &lt;ParentName&gt; non trouvé.</translation>
    </message>
    <message>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="207"/>
        <source>Not a valid ROM File.</source>
        <translation>Fichier ROM invalide.</translation>
    </message>
    <message>
        <location filename="../../src/emulation/emulatorhandler.cpp" line="197"/>
        <source>ROM file not found.</source>
        <translation>Fichier ROM manquant.</translation>
    </message>
</context>
<context>
    <name>GameSettingsDialog</name>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="20"/>
        <source>Game Settings</source>
        <translation>Paramètres du jeu</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="26"/>
        <source>Game settings for: </source>
        <translation>Paramètres du jeu pour :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="33"/>
        <source>These settings will override any global settings. If there&apos;s a setting you want to modify for this game, but it doesn&apos;t appear here, add the parameter for it to &quot;Other Parameters.&quot;</source>
        <translation>Ces paramètres prévaudront sur les paramètres généraux. Si vous souhaitez modifier un paramètre pour ce jeu, mais qu&apos;il n&apos;apparaît pas ici, ajoutez-le dans &quot;Autres paramètres.&quot;</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="43"/>
        <source>Plugins</source>
        <translation>Greffons</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="57"/>
        <source>Audio Plugin:</source>
        <translation>Greffon audio :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="64"/>
        <source>Input Plugin:</source>
        <translation>Greffon d&apos;entrée :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="71"/>
        <source>RSP Plugin:</source>
        <translation>Greffon RSP :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="78"/>
        <source>Video Plugin:</source>
        <translation>Greffon vidéo :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="86"/>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="95"/>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="104"/>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="113"/>
        <source>default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="126"/>
        <source>Additional Settings</source>
        <translation>Paramètres supplémentaires</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="137"/>
        <source>Config Directory:</source>
        <translation>Dossier de configuration :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="144"/>
        <source>Other Parameters:</source>
        <translation>Autres paramètres :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.ui" line="151"/>
        <source>Browse...</source>
        <translation>Naviguer...</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/gamesettingsdialog.cpp" line="107"/>
        <source>Config Directory</source>
        <translation>Dossier de configuration</translation>
    </message>
</context>
<context>
    <name>GridView</name>
    <message>
        <location filename="../../src/views/gridview.cpp" line="144"/>
        <source>No Cart</source>
        <translation>Pas de cartouche</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../../src/views/listview.cpp" line="158"/>
        <source>No Cart</source>
        <translation>Pas de cartouche</translation>
    </message>
</context>
<context>
    <name>LogDialog</name>
    <message>
        <location filename="../../src/dialogs/logdialog.cpp" line="47"/>
        <source>&lt;ParentName&gt; Log</source>
        <translation>Journaux &lt;ParentName&gt;</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/logdialog.cpp" line="67"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.cpp" line="250"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="251"/>
        <source>&amp;Open ROM...</source>
        <translation>&amp;Ouvrir une ROM...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="253"/>
        <source>&amp;Refresh List</source>
        <translation>&amp;Recharger la liste</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="254"/>
        <location filename="../../src/mainwindow.cpp" line="885"/>
        <source>&amp;Download/Update Info...</source>
        <translation>&amp;Télécharger/Mettre à jour les infos...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="255"/>
        <location filename="../../src/mainwindow.cpp" line="886"/>
        <source>D&amp;elete Current Info...</source>
        <translation>&amp;Effacer les infos actuelles...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="259"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="278"/>
        <source>&amp;Emulation</source>
        <translation>&amp;Émulation</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="279"/>
        <location filename="../../src/mainwindow.cpp" line="875"/>
        <source>&amp;Start</source>
        <translation>&amp;Démarrer</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="280"/>
        <source>St&amp;op</source>
        <translation>&amp;Arrêter</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="282"/>
        <source>View Log...</source>
        <translation>Consulter les journaux...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="298"/>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="299"/>
        <source>Edit mupen64plus.cfg...</source>
        <translation>Éditer mupen64plus.cfg...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="301"/>
        <location filename="../../src/mainwindow.cpp" line="878"/>
        <source>Configure &amp;Game...</source>
        <translation>Configurer le &amp;jeu...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="305"/>
        <source>&amp;Configure...</source>
        <translation>&amp;Configurer...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="713"/>
        <source>There is no log. Either &lt;ParentName&gt; has not yet run or there was no output from the last run.</source>
        <translation>Il n&apos;y a pas de journaux. Soit &lt;ParentName&gt; n’a pas encore été lancé, soit il n’y a pas de données concernant le dernier démarrage.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="319"/>
        <source>&amp;Layout</source>
        <translation>&amp;Disposition</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="318"/>
        <source>&amp;View</source>
        <translation>&amp;Affichage</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="323"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="324"/>
        <source>Table View</source>
        <translation>Vue en tableau</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="325"/>
        <source>Grid View</source>
        <translation>Vue en vignettes</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="326"/>
        <source>List View</source>
        <translation>Vue en liste</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="349"/>
        <location filename="../../src/mainwindow.cpp" line="353"/>
        <source>&amp;Full-screen</source>
        <translation>Pl&amp;ein-Écran</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="367"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="368"/>
        <source>&amp;About</source>
        <translation>À &amp;propos</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="690"/>
        <source>Not Found</source>
        <translation>Non trouvé</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="690"/>
        <source>Editor requires config directory to be </source>
        <translation>L&apos;éditeur nécessite que le dossier de configuration soit </translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="691"/>
        <source>set to a directory with mupen64plus.cfg.</source>
        <translation>un dossier contenant mupen64plus.cfg.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="692"/>
        <source>See here for the default config location:</source>
        <translation>Voir ici pour la configuration par défaut:</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="712"/>
        <source>No Output</source>
        <translation>Pas de sortie</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="765"/>
        <source>All Files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="775"/>
        <source>Open ROM File</source>
        <translation>Ouvrir un fichier ROM</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="793"/>
        <source>No ROMs</source>
        <translation>Aucune ROM</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="793"/>
        <source>No ROMs found in ZIP file.</source>
        <translation>Aucune ROM trouvée dans le fichier ZIP.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="808"/>
        <source>Select ROM</source>
        <translation>Choisir une ROM</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="825"/>
        <source>Launch</source>
        <translation>Lancer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/common.cpp" line="338"/>
        <source>GoodName</source>
        <translation>Nom Good</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="339"/>
        <source>Filename</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="340"/>
        <source>Filename (extension)</source>
        <translation>Nom du fichier (extension)</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="341"/>
        <source>Zip File</source>
        <translation>Fichier Zip</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="342"/>
        <source>Internal Name</source>
        <translation>Nom interne</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="343"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="344"/>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="345"/>
        <source>CRC1</source>
        <translation>CRC1</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="346"/>
        <source>CRC2</source>
        <translation>CRC2</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="347"/>
        <source>Players</source>
        <translation>Joueurs</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="348"/>
        <source>Rumble</source>
        <translation>Rumble</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="349"/>
        <source>Save Type</source>
        <translation>Type de sauvegarde</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="350"/>
        <source>Game Title</source>
        <translation>Titre du jeu</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="351"/>
        <source>Release Date</source>
        <translation>Date de sortie</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="352"/>
        <source>Overview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="353"/>
        <source>ESRB</source>
        <translation>ESRB</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="354"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="355"/>
        <source>Publisher</source>
        <translation>Éditeur</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="356"/>
        <source>Developer</source>
        <translation>Développeur</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="357"/>
        <source>Rating</source>
        <translation>Certification</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="358"/>
        <source>Game Cover</source>
        <translation>Jaquette</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="359"/>
        <source>Unknown ROM</source>
        <translation>ROM inconnue</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="360"/>
        <source>Requires catalog file</source>
        <translation>Fichier catalogue demandé</translation>
    </message>
    <message>
        <location filename="../../src/common.cpp" line="361"/>
        <source>Not found</source>
        <translation>Non trouvé</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="358"/>
        <source>%1 MB</source>
        <translation>%1 - MB</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="249"/>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="322"/>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="362"/>
        <source>Game Information Download</source>
        <translation>Télécharger des informations sur le jeu</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="318"/>
        <source>No results found.</source>
        <translation>Aucun résultat.</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="320"/>
        <source>No more results found.</source>
        <translation>Pas d&apos;autre résultat.</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="363"/>
        <source>Download Complete!</source>
        <translation>Téléchargement terminé !</translation>
    </message>
    <message>
        <location filename="../../src/global.h" line="44"/>
        <source>A customizable launcher for &lt;ParentName&gt; using Qt.</source>
        <translation>Une interface élémentaire pour &lt;ParentName&gt;.</translation>
    </message>
    <message>
        <location filename="../../src/global.h" line="47"/>
        <source>&lt;ParentName&gt; website</source>
        <translation>Site web de &lt;ParentName&gt;</translation>
    </message>
    <message>
        <location filename="../../src/global.h" line="50"/>
        <source>GitHub repository</source>
        <translation>Dépôt GitHub</translation>
    </message>
</context>
<context>
    <name>RomCollection</name>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="190"/>
        <location filename="../../src/roms/romcollection.cpp" line="196"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="190"/>
        <source>No ROMs found in </source>
        <translation>Aucune ROM trouvée dans</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="196"/>
        <source>No ROMs found.</source>
        <translation>Aucune ROM trouvée.</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="463"/>
        <source>Database Not Loaded</source>
        <translation>Base de données non chargée</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="464"/>
        <source>Could not connect to Sqlite database. Application may misbehave.</source>
        <translation>Impossible de se connecter à la base de données Sqlite. L&apos;application peut dysfonctionner.</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="493"/>
        <source>Loading ROMs...</source>
        <translation>Chargement des ROMS...</translation>
    </message>
    <message>
        <location filename="../../src/roms/romcollection.cpp" line="493"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="20"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="43"/>
        <source>Paths</source>
        <translation>Chemins</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="60"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="67"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="87"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="101"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="712"/>
        <source>Browse...</source>
        <translation>Naviguer...</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="49"/>
        <source>Mupen64Plus Files</source>
        <translation>Fichier Mupen64Plus</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="108"/>
        <source>Mupen64Plus executable: </source>
        <translation>Exécutable Mupen64Plus :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="149"/>
        <source>ROM Directories</source>
        <translation>Dossier des ROMS</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="191"/>
        <source>Add...</source>
        <translation>Ajouter...</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="198"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="214"/>
        <source>Emulation</source>
        <translation>Émulation</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="80"/>
        <source>Config directory:</source>
        <translation>Dossier de configuration :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="94"/>
        <source>Plugins directory:</source>
        <translation>Dossier des plugins :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="118"/>
        <source>Data directory:</source>
        <translation>Dossier des données :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="175"/>
        <source>Mupen64Plus-Qt will search for all .z64, .v64, .n64, and .zip files in these directories</source>
        <translation>Mupen64Plus-Qt cherchera tous les fichiers z64, v64, n64 et zip dans ces dossiers</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="225"/>
        <source>Cached Interpreter</source>
        <translation>Interpréteur avec cache</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="232"/>
        <source>Pure Interpreter</source>
        <translation>Interpréteur pur</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="239"/>
        <source>Dynamic Recompiler</source>
        <translation>Recompilation dynamique</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="275"/>
        <source>Graphics</source>
        <translation>Graphique</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="286"/>
        <source>On Screen Display:</source>
        <translation>Sur-affichage:</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="293"/>
        <source>Fullscreen:</source>
        <translation>Plein écran :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="300"/>
        <source>Resolution:</source>
        <translation>Résolution :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="360"/>
        <source>Plugins</source>
        <translatorcomment>Garder l&apos;anglicisme Plugins, Extensions, ou encore Plugiciel pour le Canada</translatorcomment>
        <translation>Greffons</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="368"/>
        <source>Video Plugin:</source>
        <translation>Greffon vidéo :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="375"/>
        <source>Audio Plugin:</source>
        <translation>Greffon Audio :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="382"/>
        <source>Input Plugin:</source>
        <translation>Greffon d&apos;entrée :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="389"/>
        <source>RSP Plugin:</source>
        <translation>Greffon RSP :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="424"/>
        <source>Table</source>
        <translation>Tableau</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="438"/>
        <source>Image:</source>
        <translation>Image :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="475"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="485"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="527"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="537"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="949"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="959"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="995"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1005"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="552"/>
        <source>Current Columns:</source>
        <translation>Colonnes utilisées :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="566"/>
        <source>Stretch First Column</source>
        <translation>Étendre la première colonne</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="559"/>
        <source>Available Columns:</source>
        <translation>Colonnes disponibles :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="615"/>
        <source>Grid</source>
        <translation>Vignettes</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="621"/>
        <source>ROM Label</source>
        <translation>Intitulé de la ROM</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="632"/>
        <source>Show Label:</source>
        <translation>Montrer l&apos;intitulé :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="655"/>
        <source>Label Text:</source>
        <translation>Texte de l&apos;intitulé :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="669"/>
        <source>Label Color:</source>
        <translation>Couleur de l&apos;intitulé :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="704"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1134"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="719"/>
        <source>Custom Background:</source>
        <translation>Choisir un arrière-plan :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="726"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1051"/>
        <source>Sorting:</source>
        <translation>Classement :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="736"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1044"/>
        <source>Descending</source>
        <translation>Descendant</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="753"/>
        <source>Background:</source>
        <translation>Arrière-plan:</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="768"/>
        <source>ROM Image</source>
        <translation>Images des ROMS</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="801"/>
        <source>Shadow Inactive Color:</source>
        <translation>Couleur de l’ombre des vignettes inactives :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="808"/>
        <source>Shadow Active Color:</source>
        <translation>Couleur de l’ombre de la vignette active : </translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="815"/>
        <source>Columns:</source>
        <translation>Nombre de colonnes :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="822"/>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1037"/>
        <source>Image Size:</source>
        <translation>Taille des images :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="878"/>
        <source>Adjust Automatically</source>
        <translation>Ajustage automatique</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="904"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1071"/>
        <source>First Item as Header</source>
        <translation>Premier intitulé comme en-tête</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="931"/>
        <source>Current Items:</source>
        <translation>Intitulé actuel :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1030"/>
        <source>Available Items:</source>
        <translation>Intitulés disponibles :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1078"/>
        <source>Display Cover Image</source>
        <translation>Afficher les vignettes</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1085"/>
        <source>Text Size:</source>
        <translation>Taille du texte:</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1092"/>
        <source>Theme:</source>
        <translation>Thème:</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1168"/>
        <source>Additional Parameters:</source>
        <translation>Paramètres supplémentaires :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1188"/>
        <source>Save Options:</source>
        <translation>Sauvegarder les options :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1181"/>
        <source>Download Game Information (thegamesdb.net):</source>
        <translation>Télécharger les informations sur les jeux (thegamesdb.net) :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1195"/>
        <source>Language:</source>
        <translation>Langue :</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1205"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Use to pass additional parameters to Mupen64Plus (cheats, etc.). See &lt;a href=&quot;http://mupen64plus.org/wiki/index.php?title=UIConsoleUsage&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://mupen64plus.org/wiki/index.php?title=UIConsoleUsage&lt;/span&gt;&lt;/a&gt; for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;À utiliser pour ajouter des paramètres supplémentaires (cheats, etc.). Voir &lt;a href=&quot;http://mupen64plus.org/wiki/index.php?title=UIConsoleUsage&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://mupen64plus.org/wiki/index.php?title=UIConsoleUsage&lt;/span&gt;&lt;/a&gt; pour plus d&apos;informations.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.ui" line="1240"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Language changes will not take place until application restart.</source>
        <translation>&lt;b&gt;Remarque :&lt;/b&gt; Le changement de langue ne prendra effet qu&apos;après le redémarrage du programme.</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="179"/>
        <source>Extra Small</source>
        <translation>Très petite</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="180"/>
        <source>Small</source>
        <translation>Petite</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="181"/>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="182"/>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="183"/>
        <source>Extra Large</source>
        <translation>Très grande</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="184"/>
        <source>Super</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="218"/>
        <source>Black</source>
        <translation>Noir</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="219"/>
        <source>White</source>
        <translation>Blanc</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="220"/>
        <source>Light Gray</source>
        <translation>Gris clair</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="221"/>
        <source>Dark Gray</source>
        <translation>Gris foncé</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="222"/>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="223"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="224"/>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="225"/>
        <source>Purple</source>
        <translation>Violet</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="226"/>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="227"/>
        <source>Pink</source>
        <translation>Rose</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="228"/>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="229"/>
        <source>Yellow</source>
        <translation>Jaune</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="230"/>
        <source>Brown</source>
        <translation>Marron</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="233"/>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="312"/>
        <source>Light</source>
        <translation>Lumière</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="234"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="235"/>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="313"/>
        <source>Dark</source>
        <translation>Sombre</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="420"/>
        <source>ROM Directory</source>
        <translation>Dossiers des ROMS</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="444"/>
        <source>&lt;ParentName&gt; Executable</source>
        <translation>Fichier exécutable &lt;ParentName&gt;</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="462"/>
        <source>Plugin Directory</source>
        <translation>Dossier des plugins</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="471"/>
        <source>Data Directory</source>
        <translation>Dossier des données</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="479"/>
        <source>Config Directory</source>
        <translation>Dossier de configuration</translation>
    </message>
    <message>
        <location filename="../../src/dialogs/settingsdialog.cpp" line="436"/>
        <source>Background Image</source>
        <translation>Image d&apos;arrière-plan</translation>
    </message>
</context>
<context>
    <name>TableView</name>
    <message>
        <location filename="../../src/views/tableview.cpp" line="76"/>
        <location filename="../../src/views/tableview.cpp" line="79"/>
        <source>No Cart</source>
        <translation>Pas de cartouche</translation>
    </message>
</context>
<context>
    <name>TheGamesDBScraper</name>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="103"/>
        <source>&lt;b&gt;NOTE:&lt;/b&gt; If you are deleting this game&apos;s information because the game doesn&apos;t </source>
        <translation>&lt;b&gt;Remarque :&lt;/b&gt; Si vous effacez les informations de ce jeu parce que le jeu </translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="105"/>
        <source>better to create an account on</source>
        <translation>il est préférable de créer un compte</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="106"/>
        <source>and add the game so other users can benefit as well.</source>
        <translation>et d’ajouter le jeu afin d’en faire profiter également les autres utilisateurs.</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="104"/>
        <source>exist on TheGamesDB and &lt;AppName&gt; pulled the information for different game, it&apos;s </source>
        <translation>n’est pas dans TheGamesDB et que &lt;AppName&gt; vous propose des informations pour un autre jeu, </translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="108"/>
        <source>This will cause &lt;AppName&gt; to not update the information for this game until you </source>
        <translation>&lt;AppName&gt; ne mettra pas à jour les informations jusqu&apos;à ce que vous </translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="109"/>
        <source>force it with &quot;Download/Update Info...&quot;</source>
        <translation>relanciez le &quot;Télécharger/Mettre à jour les infos...&quot;</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="111"/>
        <source>Delete the current information for</source>
        <translation>Effacer les informations actuelles pour</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="114"/>
        <source>Delete Game Information</source>
        <translation>Effacer les informations du jeu</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="223"/>
        <source>The following error from TheGamesDB occured while downloading:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="246"/>
        <source>Released on: </source>
        <translation>Publié le :</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="247"/>
        <source>Does this look correct?</source>
        <translation>Ces informations vous semblent-elles correctes ?</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="402"/>
        <source>Request timed out. Check your network settings.</source>
        <translation>Temps dépassé. Vérifier vos paramètres de connexion.</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="410"/>
        <source>Continue scraping information?</source>
        <translation>Continuer à récolter des informations ?</translation>
    </message>
    <message>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="413"/>
        <location filename="../../src/roms/thegamesdbscraper.cpp" line="415"/>
        <source>Network Error</source>
        <translatorcomment>Erreur réseau</translatorcomment>
        <translation>Erreur réseau</translation>
    </message>
</context>
</TS>
